@@ -1,7 +1,9 @@
-import re
 import subprocess  # nosec
+import warnings
 from dataclasses import dataclass
 
+import regex
+
 from pocketutils.core import PathLike
 from pocketutils.core.exceptions import ParsingError
 from pocketutils.tools.base_tools import BaseTools
@@ -45,6 +47,9 @@ class ProgramTools(BaseTools):
         """
         Gets the hex of the most recent Git commit hash in git_repo_dir.
         """
+        warnings.warn(
+            "commit_hash will be removed; use git_description instead", DeprecationWarning
+        )
         return cls.git_description(git_repo_dir).hash
 
     @classmethod
@@ -76,7 +81,7 @@ class ProgramTools(BaseTools):
 
     @classmethod
     def _parse(cls, text: str):
-        pat = re.compile(r"([\d.]+)-(\d+)-g([0-9a-h]{40})(?:-([a-z]+))?")
+        pat = regex.compile(r"([\d.]+)-(\d+)-g([0-9a-h]{40})(?:-([a-z]+))?", flags=regex.V1)
         # ex: 1.8.6-43-g0ceb89d3a954da84070858319f177abe3869752b-dirty
         m = pat.fullmatch(text)
         if m is None:
