@@ -1,9 +1,10 @@
 import json
-import re
+import warnings
 from copy import copy
-from typing import Any, Iterable, Mapping, Optional, Sequence, Tuple, TypeVar, Union, Callable
+from typing import Any, Callable, Iterable, Mapping, Optional, Sequence, Tuple, TypeVar, Union
 
 import numpy as np
+import regex
 
 from pocketutils.core import JsonEncoder
 from pocketutils.core.chars import *
@@ -34,8 +35,9 @@ class StringTools(BaseTools):
 
     @classmethod
     def extract_group_1(
-        cls, pattern: Union[str, re.Pattern], value: Optional[str], ignore_null: bool = False
+        cls, pattern: Union[str, regex.Pattern], value: Optional[str], ignore_null: bool = False
     ) -> Optional[str]:
+        warnings.warn("extract_group_1 will be removed", DeprecationWarning)
         """
         Performs a ``fullmatch`` on a target string and returns capture group 1, or None if there was no match.
 
@@ -47,7 +49,11 @@ class StringTools(BaseTools):
 
         Returns The first capture group, or None
         """
-        pattern = pattern if isinstance(pattern, re.Pattern) else re.compile(pattern)
+        pattern = (
+            pattern
+            if isinstance(pattern, regex.Pattern)
+            else regex.compile(pattern, flags=regex.V1)
+        )
         if pattern.groups != 1:
             raise ValueError(f"Pattern {pattern} has {pattern.groups} groups, not 1")
         if value is None and ignore_null:
@@ -101,7 +107,7 @@ class StringTools(BaseTools):
             n = len(m.group(1)) // nspaces
             return "\t" * n + " " * (len(m.group(1)) % nspaces)
 
-        return re.sub("^( +)", fix, s, flags=re.MULTILINE)
+        return regex.sub("^( +)", fix, s, flags=regex.V1 | regex.MULTILINE)
 
     @classmethod
     def strip_empty_decimal(cls, num: Union[float, str]) -> str:
@@ -126,7 +132,7 @@ class StringTools(BaseTools):
         """
         Splits by tabs, but preserving quoted tabs, stripping quotes.
         """
-        pat = re.compile(r"""((?:[^\t"']|"[^"]*"|'[^']*')+)""")
+        pat = regex.compile(r"""((?:[^\t"']|"[^"]*"|'[^']*')+)""", flags=regex.V1)
         # Don't strip double 2x quotes: ex ""55"" should be "55", not 55
         def strip(i: str) -> str:
             if i.endswith('"') or i.endswith("'"):
@@ -153,6 +159,8 @@ class StringTools(BaseTools):
         Returns:
             A string or None
         """
+        if always_dots is not False:
+            warnings.warn("always_dots argument will be removed", DeprecationWarning)
         if s is None and always_dots:
             return "…" * n
         if s is None:
@@ -197,9 +205,9 @@ class StringTools(BaseTools):
         return StringTools.truncate(s, 10, False)
 
     @classmethod
-    def longest_str(cls, parts: Iterable[str]) -> str:
+    def longest(cls, parts: Iterable[T]) -> T:
         """
-        Returns the argmax by length.
+        Returns an element with the highest ``len``.
         """
         mx = ""
         for i, x in enumerate(parts):
@@ -208,9 +216,16 @@ class StringTools(BaseTools):
         return mx
 
     @classmethod
-    def strip_off_start(cls, s: str, pre: str):
+    def longest_str(cls, parts: Iterable[str]) -> str:
         """
-        Strips the full string `pre` from the start of `str`.
+        Returns the argmax by length.
+        """
+        return cls.longest(parts)
+
+    @classmethod
+    def strip_off_start(cls, s: str, pre: str) -> str:
+        """
+        Strips the full string ``pre`` from the start of ``str``.
         See ``Tools.strip_off`` for more info.
         """
         if not isinstance(pre, str):
@@ -220,9 +235,9 @@ class StringTools(BaseTools):
         return s
 
     @classmethod
-    def strip_off_end(cls, s: str, suf: str):
+    def strip_off_end(cls, s: str, suf: str) -> str:
         """
-        Strips the full string `suf` from the end of `str`.
+        Strips the full string ``suf`` from the end of ``str``.
         See `Tools.strip_off` for more info.
         """
         if not isinstance(suf, str):
@@ -282,7 +297,8 @@ class StringTools(BaseTools):
     def strip_brackets(cls, text: str) -> str:
         """
         Strips any and all pairs of brackets from start and end of a string, but only if they're paired.
-        See ``strip_paired``
+        See Also:
+             strip_paired
         """
         pieces = [
             ("(", ")"),
@@ -303,7 +319,9 @@ class StringTools(BaseTools):
     def strip_quotes(cls, text: str) -> str:
         """
         Strips any and all pairs of quotes from start and end of a string, but only if they're paired.
-        See ``strip_paired``
+
+        See Also:
+            strip_paired
         """
         pieces = [
             ("`", "`"),
@@ -318,7 +336,9 @@ class StringTools(BaseTools):
     def strip_brackets_and_quotes(cls, text: str) -> str:
         """
         Strips any and all pairs of brackets and quotes from start and end of a string, but only if they're paired.
-        See ``strip_paired``
+
+        See Also:
+            strip_paired
         """
         pieces = [
             ("(", ")"),
@@ -346,7 +366,7 @@ class StringTools(BaseTools):
         Strips pairs of (start, end) from the ends of strings.
 
         Example:
-            >>> StringTools.strip_paired('[(abc]', ['()', '[]'])  # returns '(abc'
+            >>> StringTools.strip_paired("[(abc]", [("(", ")"), ("[", "]"))  # returns "(abc"
 
         Also see ``strip_brackets``
         """
@@ -368,6 +388,7 @@ class StringTools(BaseTools):
         """
         Simply replace multiple things in a string.
         """
+        warnings.warn("replace_all will be removed", DeprecationWarning)
         for k, v in rep.items():
             s = s.replace(k, v)
         return s
@@ -473,7 +494,7 @@ class StringTools(BaseTools):
 
     @classmethod
     def pretty_function(
-        cls, function, with_address: bool = False, prefix: str = "⟨", suffix: str = "⟩"
+        cls, function, *, with_address: bool = False, prefix: str = "⟨", suffix: str = "⟩"
     ) -> str:
         """
         Get a better and shorter name for a function than str(function).
@@ -494,12 +515,10 @@ class StringTools(BaseTools):
         if function is None:
             return Chars.null
         n_args = str(function.__code__.co_argcount) if hasattr(function, "__code__") else "?"
-        boundmatch = re.compile(r"^<bound method [^ .]+\.([^ ]+) of (.+)>$").fullmatch(
-            str(function)
-        )
-        objmatch = re.compile(r"<([A-Za-z0-9_.<>]+)[ ']*object").search(
-            str(function)
-        )  # instance of global or local class
+        pat = regex.compile(r"^<bound method [^ .]+\.([^ ]+) of (.+)>$", flags=regex.V1)
+        boundmatch = pat.fullmatch(str(function))
+        pat = regex.compile(r"<([A-Za-z0-9_.<>]+)[ ']*object", flags=regex.V1)
+        objmatch = pat.search(str(function))  # instance of global or local class
         addr = " @ " + hex(id(function)) if with_address else ""
         if cls.is_lambda(function):
             # simplify lambda functions!
@@ -507,7 +526,8 @@ class StringTools(BaseTools):
         elif boundmatch is not None:
             # it's a method (bound function)
             # don't show the address of the instance AND its method
-            s = re.compile(r"@ ?0x[0-9a-hA-H]+\)?$").sub("", boundmatch.group(2)).strip()
+            pat = regex.compile(r"@ ?0x[0-9a-hA-H]+\)?$", flags=regex.V1)
+            s = pat.sub("", boundmatch.group(2)).strip()
             return (
                 prefix + "`" + s + "`." + boundmatch.group(1) + "(" + n_args + ")" + addr + suffix
             )
@@ -573,7 +593,7 @@ class StringTools(BaseTools):
             if k[0].isupper() and lowercase:
                 continue
             if lowercase:
-                s = re.compile(k, re.IGNORECASE).sub(v, s)
+                s = regex.compile(k, flags=regex.V1 | regex.IGNORECASE).sub(v, s)
             else:
                 s = s.replace(k, v)
         return s
@@ -582,6 +602,7 @@ class StringTools(BaseTools):
     def join(
         cls,
         seq: Iterable[T],
+        *,
         sep: str = "\t",
         attr: Optional[str] = None,
         prefix: str = "",
@@ -612,6 +633,7 @@ class StringTools(BaseTools):
     def join_kv(
         cls,
         seq: Mapping[T, V],
+        *,
         sep: str = "\t",
         eq: str = "=",
         prefix: str = "",
